Stan Math Library: stan/math/rev/scal/fun/is_uninitialized.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_uninitialized.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_IS_UNINITIALIZED_HPP
2 #define STAN_MATH_REV_SCAL_FUN_IS_UNINITIALIZED_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/is_uninitialized.hpp>
6
7 namespace stan {
8
9 namespace math {
10
23 inline bool is_uninitialized(var x) {
24 return x.is_uninitialized();
25 }
26
27 }
28 }
29 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
is_uninitialized.hpp
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::is_uninitialized
bool is_uninitialized(T x)
Returns true if the specified variable is uninitialized.
Definition: is_uninitialized.hpp:19
stan::math::var::is_uninitialized
bool is_uninitialized()
Return true if this variable has been declared, but not been defined.
Definition: var.hpp:54

[ Stan Home Page ] © 2011–2016, Stan Development Team.